@@ -17,7 +17,7 @@ BEGIN {
 
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '2.05';
+$VERSION = '2.06';
 @ISA     = qw(Exporter);
 @EXPORT  = qw(mkpath rmtree);
 
@@ -58,7 +58,7 @@ sub mkpath {
         UNIVERSAL::isa($_[0],'ARRAY')
         or (@_ == 2 and (defined $_[1] ? $_[1] =~ /\A\d+\z/ : 1))
         or (@_ == 3
-            and (defined $_[1] ? $_[1] =~ /\A\d+\z/ : 1)
+            and (defined $_[1] ? $_[1] =~ /\A\d*\z/ : 1)
             and (defined $_[2] ? $_[2] =~ /\A\d+\z/ : 1)
         )
     ) ? 1 : 0;
@@ -135,7 +135,7 @@ sub rmtree {
         UNIVERSAL::isa($_[0],'ARRAY')
         or (@_ == 2 and (defined $_[1] ? $_[1] =~ /\A\d+\z/ : 1))
         or (@_ == 3
-            and (defined $_[1] ? $_[1] =~ /\A\d+\z/ : 1)
+            and (defined $_[1] ? $_[1] =~ /\A\d*\z/ : 1)
             and (defined $_[2] ? $_[2] =~ /\A\d+\z/ : 1)
         )
     ) ? 1 : 0;
@@ -392,8 +392,8 @@ File::Path - Create or remove directory trees
 
 =head1 VERSION
 
-This document describes version 2.05 of File::Path, released
-2008-05-07.
+This document describes version 2.06 of File::Path, released
+2008-05-08.
 
 =head1 SYNOPSIS
 
